:root {
    --main-fg: #000000;
    --main-bg: #ffffff;
    --title-fg: #81c14b;
    --entry-bg: #eeeeee;
    --entry-link-fg: #81c14b;
    --border: #dadce0;
    --button-bg: #f6f6f6;
    color-scheme: light;
}
