* {
    margin: 0;
    padding: 0;
    outline: unset;
    text-decoration: none;
    box-sizing: border-box;
}

html {
    color: var(--main-fg);
    background-color: var(--main-bg);
    font-family:
        Helvetica Neue,
        Helvetica,
        Arial,
        sans-serif;
}

a {
    color: var(--main-fg);
}

nav {
    padding: 0;
    width: 100%;
    z-index: 1000;
    display: flex;
    position: fixed;
    align-items: center;
    background-color: var(--entry-bg);
}

.inner-nav {
    margin: auto;
    display: flex;
    padding: 0 1rem;
    flex-basis: 1000px;
    align-items: center;
    box-sizing: border-box;
}

.nav-item {
    flex: 1;
    display: flex;
    line-height: 50px;
    overflow: hidden;
    flex-wrap: wrap;
    align-items: center;
}

.nav-item.right {
    text-align: right;
    justify-content: flex-end;
}

.nav-item.right a {
    padding-left: 1rem;
}

.nav-item a.site-name {
    font-size: 25px;
    font-family: FreeSerif;
}

.ozgur {
    color: var(--main-fg);
}

.sozluk {
    color: var(--title-fg);
}

.site-logo {
    height: 25px;
    width: 25px;
    margin-right: 0.5rem;
}

.container {
    margin: auto;
    /*display: flex;*/
    flex-wrap: wrap;
    max-width: 850px;
    min-height: 100vh;
    padding-top: 100px;
    box-sizing: border-box;
}

.panel-container {
    margin: auto;
}

.search-bar > form {
    margin: auto;
    padding: 12px;
    display: flex;
}

.search-bar > form input {
    border: 0;
    width: 100%;
    padding: 5px;
    height: unset;
    font-size: 15px;
    margin-right: 8px;
    border-radius: 4px;
    background: var(--main-bg);
}

.search-bar > form button {
    border: 0;
    width: 30px;
    height: 30px;
    cursor: pointer;
    font-weight: bold;
    border-radius: 3px;
    background: var(--main-bg);
}

.topic-nav {
    display: flex;
    margin: 1rem 0;
    padding: 0 0.3rem;
    align-items: center;
    justify-content: space-between;
}

.topic-nav > .topic-nav-item p {
    margin: 0;
    padding: 0;
}

.topic-nav .topic-nav-item a {
    text-decoration: underline;
}

.topic-container {
    width: 100%;
    margin: 0 auto;
}

.topic-item {
    display: flex;
    padding: 0.5rem;
    margin: 0.5rem 0;
    text-decoration: none;
    justify-content: space-between;
    background-color: var(--entry-bg);
}

.topic-entry-count small {
    opacity: 0.5;
}

.topic-container-entry-wrapper {
    gap: 0.5rem;
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr));
}

.topic-container-entry-wrapper .debe-entry {
    margin: 0;
    padding: 0.5rem;
    background-color: var(--entry-bg);
}

.entry-container {
    display: block;
    padding: 0.5rem;
    margin: 1rem 0;
    background-color: var(--entry-bg);
}

.entry-container a {
    text-decoration: underline;
}

.entry-container-items {
    text-align: right;
    padding-top: 0.5rem;
}

.entry-container a {
    text-decoration: none;
}

.entry-images-container {
    gap: 0.5rem;
    padding: 0.5rem;
    margin-top: 1rem;
    display: grid;
    border: 1px solid var(--main-bg);
}

.entry-image {
    width: 50%;
    height: auto;
    margin: auto;
    object-fit: cover;
    border-radius: 3px;
}

.author-container {
    width: 100%;
    margin: 1rem auto;
    text-align: center;
}

.author-avatar {
    border: none;
    width: 150px;
    height: 150px;
    margin: 0.5rem;
    border-radius: 50%;
}

.author-rank {
    opacity: 0.5;
    font-size: 14px;
    padding-bottom: 1rem;
}

.author-biography {
    width: 100%;
    padding: 0.5rem;
    text-align: left;
    margin: 1rem auto;
    background-color: var(--entry-bg);
}

.about-container a,
.settings-container a {
    text-decoration: underline;
}

.about-container {
    padding: 1rem;
    margin: 0.5rem 0;
    text-decoration: none;
    justify-content: space-between;
    background-color: var(--entry-bg);
}

.about-container p {
    margin: 14px 0;
    word-break: break-word;
}

.about-container ul {
    padding-left: 1.3em;
    margin-bottom: 14px;
}

.settings-container {
    padding: 1rem;
    max-width: 500px;
    margin: 0.5rem auto;
    text-decoration: none;
    justify-content: space-between;
    background-color: var(--entry-bg);
}

fieldset {
    border: 0;
    padding: 0;
}

.settings-group {
    display: block;
}

.settings-input {
    position: relative;
    margin-bottom: 6px;
}

.settings-group label {
    padding-right: 150px;
}

.settings-group select {
    top: 0;
    right: 0;
    border: none;
    display: block;
    padding: 0 2px;
    appearance: none;
    position: absolute;
    border-radius: 4px;
    color: var(--main-fg);
    background: var(--main-bg);
}

.setting-section-title,
.about-section-title {
    margin-top: 2rem;
    margin-bottom: 1rem;
    padding-bottom: 0.5rem;
    border-bottom: 1px solid var(--main-bg);
}

.checkbox-container {
    display: block;
    cursor: pointer;
    user-select: none;
    position: relative;
    margin-bottom: 5px;
    padding-right: 22px;
}

.checkbox-container input {
    opacity: 0;
    height: 0;
    width: 0;
    cursor: pointer;
    position: absolute;
}

.checkbox {
    top: 1px;
    right: 0;
    width: 17px;
    height: 17px;
    border: none;
    padding: 0 2px;
    border-radius: 4px;
    position: absolute;
    background-color: var(--main-bg);
}

.checkbox:after {
    content: "";
    display: none;
    position: absolute;
}

.checkbox-container:active input ~ .checkbox {
    border-color: var(--main-fg);
}

.checkbox-container input:checked ~ .checkbox:after {
    display: block;
}

.checkbox-container .checkbox::after {
    left: 2px;
    bottom: 0;
    font-size: 13px;
    content: "\e801";
    font-family: fontello;
}

.settings-note {
    margin-top: 20px;
    margin-bottom: 20px;
    padding: 10px 0 10px 0;
    border-top: 1px solid var(--main-bg);
    border-bottom: 1px solid var(--main-bg);
}

button {
    border: 0;
    float: right;
    padding: 5px;
    font-size: 15px;
    cursor: pointer;
    border-radius: 4px;
    color: var(--main-fg);
    background: var(--main-bg);
}

.settings button {
    margin: 6px 0 3px 0;
}

.settings-reset {
    float: left;
}

.not-found-container {
    padding: 1rem;
    margin: 0.5rem 0;
    text-decoration: none;
    justify-content: space-between;
    background-color: var(--entry-bg);
}

.not-found-title {
    margin-bottom: 1rem;
    padding-bottom: 0.5rem;
    border-bottom: 1px solid var(--main-bg);
}

.fake-button {
    cursor: pointer;
    padding: 5px;
    font-size: 15px;
    border-radius: 4px;
    color: var(--main-fg);
    text-decoration: none;
    background-color: var(--button-bg);
}

.fake-button:hover {
    opacity: 0.81;
}

.code {
    padding: 0.5rem;
    font-family: monospace;
    overflow-wrap: break-word;
    border: 1px solid var(--main-bg);
}

@media (max-width: 768px) {
    .site-logo {
        display: none;
    }

    .panel-container {
        margin-left: 1rem;
        margin-right: 1rem;
    }

    .topic-container-entry-wrapper {
        grid-template-columns: repeat(1, minmax(0, 1fr));
    }
}

/* Ekşi Sözlük Custom Class */

a.url {
    color: var(--entry-link-fg);
}

a.b {
    color: var(--entry-link-fg);
}

sup.ab a {
    color: var(--entry-link-fg);
}
