@font-face {
    font-family: "fontello";
    src: url("font/fontello.eot?49739710");
    src:
        url("font/fontello.eot?49739710#iefix") format("embedded-opentype"),
        url("font/fontello.woff2?49739710") format("woff2"),
        url("font/fontello.woff?49739710") format("woff"),
        url("font/fontello.ttf?49739710") format("truetype"),
        url("font/fontello.svg?49739710#fontello") format("svg");
    font-weight: normal;
    font-style: normal;
}

[class^="icon-"]:before,
[class*=" icon-"]:before {
    font-family: "fontello";
    font-style: normal;
    font-weight: normal;
    speak: never;

    display: inline-block;
    text-decoration: inherit;
    width: 1em;
    margin-right: 0.2em;
    text-align: center;
    /* opacity: .8; */

    /* For safety - reset parent styles, that can break glyph codes*/
    font-variant: normal;
    text-transform: none;

    /* fix buttons height, for twitter bootstrap */
    line-height: 1em;

    /* Animation center compensation - margins should be symmetric */
    /* remove if not needed */
    margin-left: 0.2em;

    /* you can be more comfortable with increased icons size */
    /* font-size: 120%; */

    /* Font smoothing. That was taken from TWBS */
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;

    /* Uncomment for 3D effect */
    /* text-shadow: 1px 1px 1px rgba(127, 127, 127, 0.3); */
}

.icon-search:before {
    content: "\e800";
} /* '' */
.icon-ok:before {
    content: "\e801";
} /* '' */
