{% extends "base.html" %}
{% block title %}About - özgürsözlük{% endblock %}
{% block meta %}<meta name="title" content="About - özgürsözlük">{% endblock %}
{% block main %}
    <div class="about-container">
        <h3 class="about-section-title" style="margin-top: 0;">About</h3>
        <p>
            This project is free alternative Ekşi Sözlük front-end focused on privacy and performance. The source is available on GitHub at <a href="https://github.com/beucismis/ozgursozluk">https://github.com/beucismis/ozgursozluk</a>. Made with <3 on the <a href="{{ url_for('topic', path='thinkpad-t61--1883047') }}">T61</a>.
        </p>
        <p>
            <ul>
                <li>No JavaScript Required – works perfectly without JS</li>
                <li>Docker Support – easy deployment and setup</li>
                <li>Topic Search – quickly find relevant discussions</li>
                <li>View Topics, Entries & Authors – browse content and contributors</li>
                <li>Gündem & Debe Page Support – full support for special pages</li>
                <li>Hide Displaying – favorite count, author and entry date</li>
                <li>Entry Images – display images directly from the source</li>
                <li>8 Built-in Themes – customize the look with 8 themes</li>
                <li>Self-Hosted, Ad-Free & Lightweight – fast, simple, and private on your server</li>
                <li>Responsive Design – optimized for mobile and small screens</li>
            </ul>
        </p>
        <p>This project is not officially affiliated with eksisozluk.com.</p>
        <p>
            Page <a href="{{ url_for("privacy_policy") }}">Privacy Policy</a> and <a href="{{ url_for("terms_of_service") }}">Terms of Service</a> for this site.
        </p>
        <h3 class="about-section-title">Donating</h3>
        <p>
            BTC: bc1q0hp2qnljdvnp938958umy5gqs7ej6ahckldua75alancwf9um8asyefd4f
            <br />
            ETH: 0xf959feb34b9736b96d6155dcb927cb8d33120fa3
            <br />
            SOL: FQUN3X36Pg5m7j8bnu4jCWxpFyiv1D7MzxkzCyNQ8rRw
            <br />
        </p>
        <h3 class="about-section-title">Contact</h3>
        <p>
            Mail: <a herf="mailto:beucismis@tutamail.com">beucismis@tutamail.com</a>
        </p>
        <h3 class="about-section-title">Instance Info</h3>
        <p>
            <a href="https://github.com/pallets/flask"><img src="https://img.shields.io/badge/flask-v{{ flask_version }}-blue" /></a>
            <a href="https://github.com/beucismis/ozgursozluk"><img src="https://img.shields.io/badge/ozgursozluk-v{{ app_version }}-blue" /></a>
            <a href="https://github.com/beucismis/limoon"><img src="https://img.shields.io/badge/limoon-v{{ limoon_version }}-blue" /></a>
        </p>
    </div>
{% endblock %}
