:root {
    --main-fg: #f2efd3;
    --main-bg: #262622;
    --title-fg: #81C14B;
    --entry-bg: #151613;
    --entry-link-fg: #81C14B;
    --border: rgba(0,0,0,.2);
    --button-bg: #1b1b18;  
    color-scheme: dark;
}
