{% extends "base.html" %}
{% block title %}
    {{ topic.title }}
    {% if page > 1 %}- page: {{ page }}{% endif %}
    - özgürsözlük
{% endblock %}
{% block meta %}
    <meta name="title" content="özgürsözlük">
    <meta name="description" content="{{ topic.title }}">
{% endblock %}
{% block main %}
    <div class="topic-nav">
        <div class="topic-nav-item">
            <p>
                {{ topic.title }} - Şükela:
                {% if topic.nice %}
                    <a href="{{ url_for('topic', path=topic.path) }}"><b>Nice</b></a>
                {% else %}
                    <a href="{{ url_for('topic', path=topic.path, a='nice') }}">Nice</a>
                {% endif %}
            </p>
        </div>
        <div class="topic-nav-item">{% include "paginate.html" %}</div>
    </div>
    <div class="topic-container">
        {% for entry in topic.entrys %}
            {% from "macros.html" import render_entry %}
            {{ render_entry(entry, True) }}
        {% endfor %}
    </div>
    <div class="topic-nav" style="padding-top: 0;">
        <div class="topic-nav-item"></div>
        <div class="topic-nav-item">{% include "paginate.html" %}</div>
    </div>
</div>
{% endblock %}
