:root {
    --main-fg: #3c3836;
    --main-bg: #fbf1c7;
    --title-fg: #81C14B;
    --entry-bg: #ebdbb2;
    --entry-link-fg: #81C14B;
    --border: #d5c4a1;
    --button-bg: #fbf1c7;
    color-scheme: light;
}
