{% extends "base.html" %}
{% block title %}Terms of Service - özgürsözlük{% endblock %}
{% block meta %}<meta name="title" content="Terms of Service  - özgürsözlük">{% endblock %}
{% block main %}
    <div class="about-container">
        <h3 class="about-section-title" style="margin-top: 0;">Terms of Service</h3>
        <p>Open Source & Free: This site is fully open-source and free to use.</p>
        <p>No User Data Stored: We do not collect or store any personal data or content you provide.</p>
        <p>Usage: You may browse, use, and contribute to the site as allowed by applicable open-source licenses.</p>
        <p>
            Limitation of Liability: The site is provided as-is. We are not responsible for any damages or loss resulting from the use of this site.
        </p>
    </div>
{% endblock %}
